==> comedi_0.7.63.orig.tar.gz: comedi-0.7.63/comedi/kcomedilib/dio.c <==
/*
    kcomedilib/dio.c
    implements comedi_dio_*() functions

    COMEDI - Linux Control and Measurement Device Interface
    Copyright (C) 2000 David A. Schleef <ds@stm.lbl.gov>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/



#include <linux/comedi.h>
#include <linux/comedidev.h>
#include <linux/comedilib.h>

#include <linux/errno.h>
#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/fcntl.h>
#include <linux/delay.h>
#include <linux/ioport.h>
#include <linux/mm.h>
#include <linux/slab.h>
#include <asm/io.h>

extern volatile int rtcomedi_lock_semaphore;

int comedi_dio_config(unsigned int dev,unsigned int subdev,unsigned int chan,
	unsigned int io)
{
	comedi_insn insn;

	memset(&insn,0,sizeof(insn));
	insn.insn = INSN_CONFIG;
	insn.n = 1;
	insn.data = &io;
	insn.subdev = subdev;
	insn.chanspec = CR_PACK(chan,0,0);

	return comedi_do_insn(dev,&insn);
}

int comedi_dio_read(unsigned int dev,unsigned int subdev,unsigned int chan,
	unsigned int *val)
{
	comedi_insn insn;

	memset(&insn,0,sizeof(insn));
	insn.insn = INSN_READ;
	insn.n = 1;
	insn.data = val;
	insn.subdev = subdev;
	insn.chanspec = CR_PACK(chan,0,0);

	return comedi_do_insn(dev,&insn);
}

int comedi_dio_write(unsigned int dev,unsigned int subdev,unsigned int chan,
	unsigned int val)
{
	comedi_insn insn;

	memset(&insn,0,sizeof(insn));
	insn.insn = INSN_WRITE;
	insn.n = 1;
	insn.data = &val;
	insn.subdev = subdev;
	insn.chanspec = CR_PACK(chan,0,0);

	return comedi_do_insn(dev,&insn);
}

int comedi_dio_bitfield(unsigned int minor,unsigned int subdev,unsigned int mask,
	unsigned int *bits)
{
	comedi_insn insn;
	lsampl_t data[2];
	int ret;

	memset(&insn,0,sizeof(insn));
	insn.insn = INSN_BITS;
	insn.n = 2;
	insn.data = data;
	insn.subdev = subdev;

	data[0] = mask;
	data[1] = *bits;

	ret = comedi_do_insn(minor,&insn);

	*bits = data[1];

	return ret;
}

==> comedi_0.7.70.orig.tar.gz: comedi-0.7.70/comedi/kcomedilib/dio.c <==
/*
    kcomedilib/dio.c
    implements comedi_dio_*() functions

    COMEDI - Linux Control and Measurement Device Interface
    Copyright (C) 2000 David A. Schleef <ds@schleef.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#include <linux/comedi.h>
#include <linux/comedilib.h>

#include <linux/string.h>


int comedi_dio_config(comedi_t * dev,unsigned int subdev,unsigned int chan,
	unsigned int io)
{
	comedi_insn insn;

	memset(&insn,0,sizeof(insn));
	insn.insn = INSN_CONFIG;
	insn.n = 1;
	insn.data = &io;
	insn.subdev = subdev;
	insn.chanspec = CR_PACK(chan,0,0);

	return comedi_do_insn(dev,&insn);
}

int comedi_dio_read(comedi_t * dev,unsigned int subdev,unsigned int chan,
	unsigned int *val)
{
	comedi_insn insn;

	memset(&insn,0,sizeof(insn));
	insn.insn = INSN_READ;
	insn.n = 1;
	insn.data = val;
	insn.subdev = subdev;
	insn.chanspec = CR_PACK(chan,0,0);

	return comedi_do_insn(dev,&insn);
}

int comedi_dio_write(comedi_t * dev,unsigned int subdev,unsigned int chan,
	unsigned int val)
{
	comedi_insn insn;

	memset(&insn,0,sizeof(insn));
	insn.insn = INSN_WRITE;
	insn.n = 1;
	insn.data = &val;
	insn.subdev = subdev;
	insn.chanspec = CR_PACK(chan,0,0);

	return comedi_do_insn(dev,&insn);
}

int comedi_dio_bitfield(comedi_t *dev,unsigned int subdev,unsigned int mask,
	unsigned int *bits)
{
	comedi_insn insn;
	lsampl_t data[2];
	int ret;

	memset(&insn,0,sizeof(insn));
	insn.insn = INSN_BITS;
	insn.n = 2;
	insn.data = data;
	insn.subdev = subdev;

	data[0] = mask;
	data[1] = *bits;

	ret = comedi_do_insn(dev,&insn);

	*bits = data[1];

	return ret;
}
